

/**********************Table 1********************************/;
clear
use intervention043019.dta 
sort cty1 date
drop if cty1==cty1[_n-1] & date==date[_n-1]
keep cty1 COUNTRY date newdepositinsurance newdebtguarantees newrecap newassetpurchase newliquiditysupport
gen a1=1
by cty1: egen totaldates=sum(a1)
by cty1: egen totalnewdepositinsurance=sum( newdepositinsurance)
by cty1: egen totalnewdebtguarantees=sum( newdebtguarantees)
by cty1: egen totalnewrecap=sum( newrecap)
by cty1: egen totalnewassetpurchase=sum( newassetpurchase)
by cty1: egen totalnewliquiditysupport=total( newliquiditysupport)
drop if cty1==cty1[_n-1]
sort COUNTRY
list COUNTRY total*

/***************Table 2**************************************************/
/***Firm-level stock returns and abnormal stock return**********/
clear
use intervention043019.dta
tabstat newchgp  newf2,stat(N median mean sd min max) col(stat)

/***Firms size, book-to-market ratio and leverage***************/
sort id date
tabstat  lnta mybr newlevarage if id~=id[_n-1],stat(N median mean sd min max) col(stat)

/***Sector level variables***************/
sort sic3 date
tabstat  lnta mybr newlevarage if sic3~=sic3[_n-1],stat(N median mean sd min max) col(stat)

/****firm-level change of real activities**********/
clear
use realeffects043019.dta
sort id
tabstat   chgce chgrd  chgno if id~=id[_n-1],stat(N median mean sd min max) col(stat)



/**********************Table 3 *****************************/
clear
use intervention043019.dta 


areg newchgp mywork , absorb(t1) clu(sic3)
areg newf2 mywork , absorb(t1) clu(sic3)
areg newf2 mywork lnta sensi mybr , absorb(t1) clu(sic3)
areg newf2 mywork lnta sensi mybr newlevarage, absorb(t1) clu(sic3)
areg newf2 mywork lnta sensi mybr newlevarage if mynewever0811~=1 , absorb(t1) clu(sic3)


 
 ******************************Table 4******************************************************;
clear
use intervention043019.dta 
egen t1sic3=group(t1 sic3)

areg newf2 c3 mywork lnta , absorb(t1) clu(t1sic3)
 
areg newf2 c3 lnta i.sic3, absorb(t1) clu(t1sic3)
 
areg newf2 qs1c2 lnta i.sic3, absorb(t1) clu(t1sic3) 
 
areg newf2 rzc2 lnta i.sic3, absorb(t1) clu(t1sic3)

areg newf2 c3 lnta i.sic3 if deve==1,	absorb(t1) clu(t1sic3)

 
*************table 5*******************************; 
clear
use interventionextra043019.dta 
sort cty1 date
gen year=year(date)
xi: reg newc2 inter i.cty1*i.year if  (cty1~=cty1[_n-1] | date~=date[_n-1])

************table 6**********************************;
clear
use interventionextra043019.dta 
egen t1sic3=group(t1 sic3)
lab var t1sic3 "Country-date-sector dummy"

areg newf2 c3 i.sic3, absorb(t1) clu(t1sic3)
areg newf2 prec3 i.sic3, absorb(t1) clu(t1sic3)

*************table 7******************
clear
use interventionextra043019.dta 
egen t1sic3=group(t1 sic3)
lab var t1sic3 "Country-date-sector dummy"
gen btmp1=newrecap*prec3
gen btmp2=newdebt*prec3
gen btmp3=newass*prec3
gen btmp4=newdepo*prec3
gen btmp5=newliquiditysupport*prec3
gen xtmp1=newrecap*c3
gen xtmp2=newdebt*c3
gen xtmp3=newass*c3
gen xtmp4=newdepo*c3
gen xtmp5=newliquiditysupport*c3

areg newf2 btmp* i.sic3 if inter==1 & sumtype==1, absorb(t1) clu(t1sic3) 
areg newf2 xtmp* i.sic3 if inter==1 & sumtype==1, absorb(t1) clu(t1sic3)
 

*************Table 8*********************
clear
use realeffects043019.dta
areg chgce x1 i.cty1, a(sic3) clu(z1)
areg chgrd x1  i.cty1 , a(sic3) clu(z1)
areg chgno  x1  i.cty1, a(sic3) clu(z1)
areg chgce x2 i.cty1, a(sic3) clu(z1)
areg chgrd x2  i.cty1, a(sic3) clu(z1)
areg chgno  x2 i.cty1, a(sic3) clu(z1)


/*Table 9*/
clear
use realeffects043019.dta
xi: areg chgce i.w1|x1 i.cty1 , a(sic3) clu(z1)
xi: areg chgrd i.w1|x1  i.cty1, a(sic3) clu(z1)
xi: areg chgno  i.w1|x1  i.cty1, a(sic3) clu(z1)
xi: areg chgce i.w1|x2 i.cty1, a(sic3) clu(z1)
xi: areg chgrd i.w1|x2  i.cty1, a(sic3) clu(z1)
xi: areg chgno  i.w1|x2  i.cty1, a(sic3) clu(z1) 
 
 
**********************Figure 1********************************************* 
use  intervention043019.dta
sort cty1 date
drop if cty1==cty1[_n-1] & date==date[_n-1]
keep cty1 date
gen year=year(date)
gen month=month(date)
sort year month
gen a1=1
by year month: egen a2=total(a1)
drop if year==year[_n-1] & month==month[_n-1]
keep year month a2 
lab var a2 "Number of interventions" 
list year month a2
 
******************Appendix Table 1*******************************************;
use  intervention043019.dta
sort id date
drop if id==id[_n-1]
sort COUNTRY
gen a1=1
by COUNTRY: egen firmnumbers=total(a1)
drop if COUNTRY==COUNTRY[_n-1]
list COUNTRY firmnumbers 
